# Table of Contents

- [okta-integration-for-saas-discovery](<./okta-integration-for-saas-discovery.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Okta Integration for SaaS Discovery](<./Okta-Integration-for-SaaS-Discovery.md>)
  - [Introduction](<./Okta-Integration-for-SaaS-Discovery/Introduction.md>)
  - [Implementation Details](<./Okta-Integration-for-SaaS-Discovery/Implementation-Details.md>)
  - [Discovery Capabilities](<./Okta-Integration-for-SaaS-Discovery/Discovery-Capabilities.md>)
  - [Setting up Okta Integration](<./Okta-Integration-for-SaaS-Discovery/Setting-up-Okta-Integration.md>)
  - [Enable API Service Integration in Okta](<./Okta-Integration-for-SaaS-Discovery/Enable-API-Service-Integration-in-Okta.md>)
  - [Enter the Copied Credentials in SAP LeanIX](<./Okta-Integration-for-SaaS-Discovery/Enter-the-Copied-Credentials-in-SAP-LeanIX.md>)
